### Name: mpl
### Title: Fit Point Process Model by Maximum Pseudolikelihood
### Aliases: mpl
### Keywords: spatial

### ** Examples

 ##Don't run: library(spatstat)
 data(nztrees)
 Q <- quadscheme(nztrees) # default quadrature scheme
 mpl(Q)
 # fit the stationary Poisson process
 # to point pattern or data/dummy quadrature scheme Q

 mpl(Q, ~ x)
 # fit the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(a + bx)
 # where x,y are the Cartesian coordinates
 # and a,b are parameters to be estimated

 mpl(Q, ~ polynom(x,2))
 # fit the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(a + bx + cx^2)

 library(splines)
 mpl(Q, ~ bs(x,df=3))
 #       WARNING: do not use predict.ppm() on this result
 # Fits the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(B(x))
 # where B is a B-spline with df = 3
 
 mpl(Q, ~1, Strauss(r=0.1), rbord=0.1)
 # Fit the stationary Strauss process with interaction range 0.1
 # using the border method with margin rbord=0.1
  
 mpl(Q, ~ x, Strauss(0.1), correction="periodic")
 # Fit the nonstationary Strauss process with interaction range 0.07
 # and exp(first order potential) =  activity = beta(x,y) = exp(a+bx)
 # using the periodic correction.

 ##Don't run: 
##D  data(soilsurvey)
##D  mpl(soilsurvey, ~ bs(pH,3), Strauss(0.1), rbord=0.1, data=soilchem)
##D  #       WARNING: do not use predict.ppm() on this result
##D  # Fit the nonstationary Strauss process 
##D  # with intensity modelled as a third order spline function of the 
##D  # spatial variable "pH" in data frame 'soilchem'
##D  

 ## MULTITYPE POINT PROCESSES ### 
 data(lansing)
 # Multitype point pattern --- trees marked by species
 mpl(lansing, ~ marks, Poisson())
 # fit stationary marked Poisson process
 # with different intensity for each species

##Don't run: 
##D  mpl(lansing, ~ marks * polynom(x,y,3), Poisson())

 # fit nonstationary marked Poisson process
 # with different log-cubic trend for each species

 # equivalent functionality - smaller dataset
 data(ganglia)
 mpl(ganglia, ~ marks * polynom(x,y,2), Poisson())




